#
# spec file for package xf86-video-voodoo
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-video-voodoo
Version:        1.2.6
Release:        2.2
Summary:        Voodoo video driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            https://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.xz
Source1:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.xz.sig
Source2:        xf86-video-voodoo.keyring
Patch2:         0002-configure-Use-LT_INIT-from-libtool-2-instead-of-depr.patch
Patch3:         0003-Add-X.Org-s-standard-C-warning-flags-to-AM_CFLAGS.patch
Patch4:         0004-Quiet-Wredundant-decls-from-xorg-os.h-fallbacks-for-.patch
Patch5:         0005-Fix-3-Wunused-but-set-variable-warnings.patch
Patch6:         0006-Fix-4-Wunused-variable-warnings.patch
Patch7:         0007-voodoo_find_dac-doesn-t-check-device_ids-2.patch
Patch8:         0008-use-XNFalloc-instead-of-xnfalloc.patch
Patch9:         0009-use-XNFcallocarray-instead-of-xnfcalloc-macro.patch
Patch10:        0010-bump-minimal-xorg-version-to-1.18.patch
Patch11:        0011-drop-compat-with-ancient-xserver-versions.patch
Patch12:        0012-Drop-ifdefs-for-ABI_VIDEODRV_VERSION-6.patch
Patch13:        0013-Remove-XAA-support.patch
Patch14:        0014-drop-dead-code.patch
Patch15:        0015-drop-remains-of-old-compat-code.patch
Patch20:        u_buildfix.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(pciaccess) >= 0.8.0
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xf86dgaproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.0.99.901
BuildRequires:  pkgconfig(xproto)
Supplements:    modalias(xorg-x11-server:pci:v0000121Ad*sv*sd*bc03sc*i*)
# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
ExcludeArch:    s390 s390x
%{?x11_abi_videodrv_req}

%description
voodoo is an Xorg driver for Voodoo 1 and Voodoo 2 series video cards.

On the Voodoo 1 the driver uses a shadow buffer in system memory as the
video adapter has only 3D acceleration. Selected portions of the shadow
framebuffer are copied out to the Voodoo board at the right time.
Because of this, the speed of the driver is very dependent on the CPU.
Processors nowadays are actually rather fast at moving data so we get
very good speed anyway as the shadow framebuffer is in cached RAM.

The Voodoo2 has 16bpp acceleration and the driver provides accelerated
versions of most operations except angled lines and stipples.
Accelerated alpha blending with the Render extension is also supported
as is DGA.

This driver supports 16bpp modes currently. The video hardware supports
image conversion from 24bpp to 16bpp but the hardware is 16bpp only.

The Voodoo 1 series cards can go up to 800x600 resolution while the
Voodoo 2 can reach 1024x768 providing it has at least 2Mb of frame
buffer memory. 1024x768 2D mode does not require two cards configured in
scan-line interleave mode (SLI).

Multihead and Xinerama configurations are supported. SLI configurations
will be treated as multiple video cards.

Limited support for DPMS screen saving is available. The "standby" and
"suspend" modes are just painting the screen black. The "off" mode turns
the Voodoo board off and thus works correctly.

This driver does not support a virtual screen size different from the
display size. This is a hardware limitation. 3D rendering is also not
supported.

%prep
%autosetup -p1

%build
autoreconf --force
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%files
%license COPYING
%doc ChangeLog README
%dir %{_libdir}/xorg/modules/drivers
%{_libdir}/xorg/modules/drivers/voodoo_drv.so
%{_mandir}/man4/voodoo.4%{?ext_man}

%changelog
* Wed Dec 11 2024 Stefan Dirsch <sndirsch@suse.com>
- 0002-configure-Use-LT_INIT-from-libtool-2-instead-of-depr.patch
  0003-Add-X.Org-s-standard-C-warning-flags-to-AM_CFLAGS.patch
  0004-Quiet-Wredundant-decls-from-xorg-os.h-fallbacks-for-.patch
  0005-Fix-3-Wunused-but-set-variable-warnings.patch
  0006-Fix-4-Wunused-variable-warnings.patch
  0007-voodoo_find_dac-doesn-t-check-device_ids-2.patch
  0008-use-XNFalloc-instead-of-xnfalloc.patch
  0009-use-XNFcallocarray-instead-of-xnfcalloc-macro.patch
  0010-bump-minimal-xorg-version-to-1.18.patch
  0011-drop-compat-with-ancient-xserver-versions.patch
  0012-Drop-ifdefs-for-ABI_VIDEODRV_VERSION-6.patch
  0013-Remove-XAA-support.patch
  0014-drop-dead-code.patch
  0015-drop-remains-of-old-compat-code.patch
  * latest changes to fix build against current xserver
- u_buildfix.patch
  * fixes build on i586 (hopefully)
* Sun Dec 18 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.6:
  * Remove miInitializeBackingStore
    Stop using deprecated xf86PciInfo.h
    Fix spelling/wording issues
    Build xz tarballs instead of bzip2
    Update configure.ac bug URL for gitlab migration
    autogen: add default patch prefix
    autogen.sh: use quoted string variables
    autogen.sh: use exec instead of waiting for configure to finish
    autogen.sh: Honor NOCONFIGURE=1
    configure: Drop AM_MAINTAINER_MODE
    don't use PCITAG in struct anymore
- drop U_don-t-use-PCITAG-in-struct-anymore.patch (upstream)
* Fri Feb  6 2015 sndirsch@suse.com
- U_don-t-use-PCITAG-in-struct-anymore.patch
  * fixes build against xorg-server 1.17
* Wed Aug  7 2013 ro@suse.de
- add ExcludeArch for s390 and s390x
* Wed Mar 20 2013 sndirsch@suse.com
- introduce hardware supplements conditional on xorg-x11-server
  package (bnc#810333)
* Sun Sep  2 2012 zaitor@opensuse.org
- Update to version 1.2.5:
  + Fix build against older X servers.
  + Fix build against XAA-less server.
  + Drop useless vgaHW include.
  + Fall back to shadowfb if XAA is unavailable.
* Fri Apr 20 2012 vuntz@opensuse.org
- Use %%x11_abi_videodrv_req instead of static ABI Requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-video-voodoo from xorg-x11-driver-video.
  Initial version: 1.2.4.
